<?php

/**
 * The file that defines the core plugin class
 *
 * A class definition that includes attributes and functions used across both the
 * public-facing side of the site and the admin area.
 *
 * @link       https://aditbaco.com
 * @since      1.0.0
 *
 * @package    Rsdkconline_Plugin
 * @subpackage Rsdkconline_Plugin/includes
 */

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.0.0
 * @package    Rsdkconline_Plugin
 * @subpackage Rsdkconline_Plugin/includes
 * @author     aditbaco <aditya.wahyudi@rsdkciamis.com>
 */
class RsdkcOnlineApi
{
    public static function persediaanKamar()
    {
        $curl = curl_init();

        curl_setopt_array($curl, array(
          CURLOPT_URL => "http://admin.antrean.rsdkciamis.com/api/pasien/kamar/persediaan",
          CURLOPT_RETURNTRANSFER => true,
          CURLOPT_ENCODING => "",
          CURLOPT_MAXREDIRS => 10,
          CURLOPT_TIMEOUT => 0,
          CURLOPT_FOLLOWLOCATION => true,
          CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
          CURLOPT_CUSTOMREQUEST => "GET",
          CURLOPT_HTTPHEADER => array(
            "Content-Type: application/json",
            "Accept: application/json",
            "X-RSDK-API: 18"
          ),
        ));

        $response = curl_exec($curl);

        curl_close($curl);
        
        $response = json_decode($response, true);

        if ($response && isset($response['status']) && $response['status'] === 'success' && isset($response['data']['persediaan_kamar'])) {
            return $response['data'];
        }

        return [];
	}   

	public static function ruanganOperasi()
    {
        $curl = curl_init();

        curl_setopt_array($curl, array( 
          CURLOPT_URL => "http://admin.antrean.rsdkciamis.com/api/pasien/ruangan/operasi",
          CURLOPT_RETURNTRANSFER => true,
          CURLOPT_ENCODING => "",
          CURLOPT_MAXREDIRS => 10,
          CURLOPT_TIMEOUT => 0,
          CURLOPT_FOLLOWLOCATION => true,
          CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
          CURLOPT_CUSTOMREQUEST => "GET",
          CURLOPT_HTTPHEADER => array(
            "Content-Type: application/json",
            "Accept: application/json",
            "X-RSDK-API: 18"
          ),
        ));

        $response = curl_exec($curl);
        curl_close($curl);
        
        $response = json_decode($response, true);

        if ($response && isset($response['status']) && $response['status'] === 'success' && isset($response['data']['jadwal_operasi'])) {
            return $response['data'];
        }

        return [];
    }
}



class Rsdkconline_Plugin {

	/**
	 * The loader that's responsible for maintaining and registering all hooks that power
	 * the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      Rsdkconline_Plugin_Loader    $loader    Maintains and registers all hooks for the plugin.
	 */
	protected $loader;

	/**
	 * The unique identifier of this plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $plugin_name    The string used to uniquely identify this plugin.
	 */
	protected $plugin_name;

	/**
	 * The current version of the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $version    The current version of the plugin.
	 */
	protected $version;

	/**
	 * Define the core functionality of the plugin.
	 *
	 * Set the plugin name and the plugin version that can be used throughout the plugin.
	 * Load the dependencies, define the locale, and set the hooks for the admin area and
	 * the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function __construct() {
		if ( defined( 'RSDKCONLINE_PLUGIN_VERSION' ) ) {
			$this->version = RSDKCONLINE_PLUGIN_VERSION;
		} else {
			$this->version = '1.0.0';
		}
		$this->plugin_name = 'rsdkconline-plugin';

		$this->load_dependencies();
		$this->set_locale();
		$this->define_admin_hooks();
		$this->define_public_hooks();
		
		add_shortcode('rsdkconline-room-avail', function ($atts) {
			$content = <<<HTML
    <table class="table">
        <thead>
        <tr>
            <th>Kelas</th>
            <th>Kapasitas</th>
            <th>Tersedia</th>
            <th>Terpakai</th>
        </tr>
        </thead>
        <tbody>
HTML;
	$rooms = RsdkcOnlineApi::persediaanKamar();
	$server_time = $rooms ['last_fetched'];

	$rooms = $rooms ['persediaan_kamar'];

    foreach ($rooms as $room) {
        $kelas = $room['kelas'];
        $total = $room['total'];
        $tersedia = $room['tersedia'];
        $terpakai = $room['terpakai'];

        $content .= <<<HTML
		<tr>
            <td>$kelas</td>
            <td>$total</td>
            <td>$tersedia</td>
            <td>$terpakai</td>
        </tr>
HTML;
    }


    $content .= <<<HTML
        </tbody>
    </table>
	*Terakhir diperbarui pada $server_time (Waktu Server)
HTML;
			return $content;
		});
		
		add_shortcode('rsdkconline-op-schedule', function ($atts) {
			$content = <<<HTML
    <table class="table">
        <thead>
        <tr>
            <th>Dokter</th>
            <th>Spesialis</th>
            <th>Tanggal</th>
        </tr>
        </thead>
        <tbody>
HTML;
    $rooms = RsdkcOnlineApi::ruanganOperasi();
    $server_time = $rooms ['last_fetched'];

    $rooms = $rooms ['jadwal_operasi'];
			if (count($rooms) > 0) {
				
    foreach ($rooms as $room) {
        $nama_dokter = $room['nama_dokter'];
        $nama_smf = $room['nama_smf'];
        $tanggal = $room['tanggal'];

        $content .= <<<HTML
        <tr>
            <td>$nama_dokter</td>
            <td>$nama_smf</td>
            <td>$tanggal</td>
        </tr>
HTML;
	}
} else {
$content .= <<<HTML
		<tr>
            <td colspan="3" style="color:blue"><b><i>Belum ada data yang terjadwal.</b></i></td>
        </tr>
HTML;
}
    $content .= <<<HTML
        </tbody>
    </table>
    *Terakhir diperbarui pada $server_time (Waktu Server)
HTML;
            return $content;

		});

	}

	/**
	 * Load the required dependencies for this plugin.
	 *
	 * Include the following files that make up the plugin:
	 *
	 * - Rsdkconline_Plugin_Loader. Orchestrates the hooks of the plugin.
	 * - Rsdkconline_Plugin_i18n. Defines internationalization functionality.
	 * - Rsdkconline_Plugin_Admin. Defines all hooks for the admin area.
	 * - Rsdkconline_Plugin_Public. Defines all hooks for the public side of the site.
	 *
	 * Create an instance of the loader which will be used to register the hooks
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function load_dependencies() {

		/**
		 * The class responsible for orchestrating the actions and filters of the
		 * core plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-rsdkconline-plugin-loader.php';

		/**
		 * The class responsible for defining internationalization functionality
		 * of the plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-rsdkconline-plugin-i18n.php';

		/**
		 * The class responsible for defining all actions that occur in the admin area.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/class-rsdkconline-plugin-admin.php';

		/**
		 * The class responsible for defining all actions that occur in the public-facing
		 * side of the site.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/class-rsdkconline-plugin-public.php';

		$this->loader = new Rsdkconline_Plugin_Loader();

	}

	/**
	 * Define the locale for this plugin for internationalization.
	 *
	 * Uses the Rsdkconline_Plugin_i18n class in order to set the domain and to register the hook
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function set_locale() {

		$plugin_i18n = new Rsdkconline_Plugin_i18n();

		$this->loader->add_action( 'plugins_loaded', $plugin_i18n, 'load_plugin_textdomain' );

	}

	/**
	 * Register all of the hooks related to the admin area functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_admin_hooks() {

		$plugin_admin = new Rsdkconline_Plugin_Admin( $this->get_plugin_name(), $this->get_version() );

		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_styles' );
		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_scripts' );

	}

	/**
	 * Register all of the hooks related to the public-facing functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_public_hooks() {

		$plugin_public = new Rsdkconline_Plugin_Public( $this->get_plugin_name(), $this->get_version() );

		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_styles' );
		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_scripts' );

	}

	/**
	 * Run the loader to execute all of the hooks with WordPress.
	 *
	 * @since    1.0.0
	 */
	public function run() {
		$this->loader->run();
	}

	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality.
	 *
	 * @since     1.0.0
	 * @return    string    The name of the plugin.
	 */
	public function get_plugin_name() {
		return $this->plugin_name;
	}

	/**
	 * The reference to the class that orchestrates the hooks with the plugin.
	 *
	 * @since     1.0.0
	 * @return    Rsdkconline_Plugin_Loader    Orchestrates the hooks of the plugin.
	 */
	public function get_loader() {
		return $this->loader;
	}

	/**
	 * Retrieve the version number of the plugin.
	 *
	 * @since     1.0.0
	 * @return    string    The version number of the plugin.
	 */
	public function get_version() {
		return $this->version;
	}

}
